@@ -17,15 +17,15 @@ class IndexingError(SdkError):
         super().__init__(message)
 
 
-class ToolLLMError(SdkError):
+class LLMError(SdkError):
     DEFAULT_MESSAGE = "Error ocurred related to LLM"
 
 
-class ToolEmbeddingError(SdkError):
+class EmbeddingError(SdkError):
     DEFAULT_MESSAGE = "Error ocurred related to embedding"
 
 
-class ToolVectorDBError(SdkError):
+class VectorDBError(SdkError):
     DEFAULT_MESSAGE = "Error ocurred related to vector DB"
 
 
@@ -33,5 +33,9 @@ class X2TextError(SdkError):
     DEFAULT_MESSAGE = "Error ocurred related to text extractor"
 
 
+class OCRError(SdkError):
+    DEFAULT_MESSAGE = "Error ocurred related to OCR"
+
+
 class RateLimitError(SdkError):
     DEFAULT_MESSAGE = "Running into rate limit errors, please try again later"
