@@ -1,12 +1,15 @@
+import logging
 from typing import Any, Optional
 
 import requests
-from requests import RequestException, Response
+from requests import ConnectionError, RequestException, Response
 
 from unstract.sdk.constants import LogLevel, PromptStudioKeys, ToolEnv
 from unstract.sdk.helper import SdkHelper
 from unstract.sdk.tool.base import BaseTool
 
+logger = logging.getLogger(__name__)
+
 
 class PromptTool:
     """Class to handle prompt service methods for Unstract Tools."""
@@ -16,39 +19,64 @@ class PromptTool:
         tool: BaseTool,
         prompt_host: str,
         prompt_port: str,
+        is_public_call: bool = False,
     ) -> None:
         """
         Args:
             tool (AbstractTool): Instance of AbstractTool
             prompt_host (str): Host of platform service
             prompt_host (str): Port of platform service
-
         """
         self.tool = tool
-        self.base_url = SdkHelper.get_platform_base_url(
-            prompt_host, prompt_port
+        self.base_url = SdkHelper.get_platform_base_url(prompt_host, prompt_port)
+        self.is_public_call = is_public_call
+        if not is_public_call:
+            self.bearer_token = tool.get_env_or_die(ToolEnv.PLATFORM_API_KEY)
+
+    def answer_prompt(
+        self, payload: dict[str, Any], params: Optional[dict[str, str]] = None
+    ) -> dict[str, Any]:
+        url_path = "answer-prompt"
+        if self.is_public_call:
+            url_path = "answer-prompt-public"
+        return self._post_call(
+            url_path=url_path,
+            payload=payload,
+            params=params,
         )
-        self.bearer_token = tool.get_env_or_die(ToolEnv.PLATFORM_API_KEY)
 
-    def answer_prompt(self, payload: dict[str, Any]) -> dict[str, Any]:
-        return self._post_call("answer-prompt", payload)
+    def single_pass_extraction(
+        self, payload: dict[str, Any], params: Optional[dict[str, str]] = None
+    ) -> dict[str, Any]:
+        return self._post_call(
+            url_path="single-pass-extraction",
+            payload=payload,
+            params=params,
+        )
 
-    def single_pass_extraction(self, payload: dict[str, Any]) -> dict[str, Any]:
-        return self._post_call("single-pass-extraction", payload)
+    def summarize(
+        self, payload: dict[str, Any], params: Optional[dict[str, str]] = None
+    ) -> dict[str, Any]:
+        return self._post_call(url_path="summarize", payload=payload, params=params)
 
     def _post_call(
-        self, url_path: str, payload: dict[str, Any]
+        self,
+        url_path: str,
+        payload: dict[str, Any],
+        params: Optional[dict[str, str]] = None,
     ) -> dict[str, Any]:
         """Invokes and communicates to prompt service to fetch response for the
         prompt.
 
         Args:
-            file_name (str): File in which the prompt is processed
-            outputs (dict): dict of all input data for the tool
-            tool_id (str): Unique ID of the tool to be processed
+            url_path (str): URL path to the service endpoint
+            payload (dict): Payload to send in the request body
+            params (dict, optional): Query parameters to include in the request
 
         Returns:
-            Sample return dict:
+            dict: Response from the prompt service
+
+            Sample Response:
             {
                 "status": "OK",
                 "error": "",
@@ -63,17 +91,24 @@ class PromptTool:
             "structure_output": "",
         }
         url: str = f"{self.base_url}/{url_path}"
-        headers: dict[str, str] = {
-            "Authorization": f"Bearer {self.bearer_token}"
-        }
+        headers: dict[str, str] = {}
+        if not self.is_public_call:
+            headers = {"Authorization": f"Bearer {self.bearer_token}"}
+        response: Response = Response()
         try:
-            # TODO: Review timeout value
-            response: Response = requests.post(
-                url, json=payload, headers=headers, timeout=600
+            response = requests.post(
+                url=url,
+                json=payload,
+                params=params,
+                headers=headers
             )
             response.raise_for_status()
             result["status"] = "OK"
             result["structure_output"] = response.text
+        except ConnectionError as connect_err:
+            msg = "Unable to connect to prompt service. Please contact admin."
+            self._stringify_and_stream_err(connect_err, msg)
+            result["error"] = msg
         except RequestException as e:
             # Extract error information from the response if available
             error_message = str(e)
@@ -91,6 +126,12 @@ class PromptTool:
             )
         return result
 
+    def _stringify_and_stream_err(self, err: RequestException, msg: str) -> None:
+        error_message = str(err)
+        trace = f"{msg}: {error_message}"
+        self.tool.stream_log(trace, level=LogLevel.ERROR)
+        logger.error(trace)
+
     @staticmethod
     def get_exported_tool(
         tool: BaseTool, prompt_registry_id: str
