@@ -8,6 +8,7 @@ from llama_index.core.llms import LLM
 from unstract.sdk.audit import Audit
 from unstract.sdk.constants import LogLevel
 from unstract.sdk.tool.stream import StreamMixin
+from unstract.sdk.utils.token_counter import TokenCounter
 
 
 class UsageHandler(StreamMixin, BaseCallbackHandler):
@@ -32,17 +33,17 @@ class UsageHandler(StreamMixin, BaseCallbackHandler):
 
     def __init__(
         self,
-        token_counter: TokenCountingHandler,
         platform_api_key: str,
+        token_counter: Optional[TokenCountingHandler] = None,
         llm_model: LLM = None,
         embed_model: BaseEmbedding = None,
         event_starts_to_ignore: Optional[list[CBEventType]] = None,
         event_ends_to_ignore: Optional[list[CBEventType]] = None,
         verbose: bool = False,
         log_level: LogLevel = LogLevel.INFO,
-        **kwargs,
+        kwargs: dict[Any, Any] = None,
     ) -> None:
-        self.kwargs = kwargs
+        self.kwargs = kwargs.copy()
         self._verbose = verbose
         self.token_counter = token_counter
         self.llm_model = llm_model
@@ -70,7 +71,7 @@ class UsageHandler(StreamMixin, BaseCallbackHandler):
         payload: Optional[dict[str, Any]] = None,
         event_id: str = "",
         parent_id: str = "",
-        **kwargs: Any,
+        kwargs: dict[Any, Any] = None,
     ) -> str:
         return event_id
 
@@ -79,7 +80,7 @@ class UsageHandler(StreamMixin, BaseCallbackHandler):
         event_type: CBEventType,
         payload: Optional[dict[str, Any]] = None,
         event_id: str = "",
-        **kwargs: Any,
+        kwargs: dict[Any, Any] = None,
     ) -> None:
         """Push the usage of  LLM or Embedding to platform service."""
         if (
@@ -89,13 +90,14 @@ class UsageHandler(StreamMixin, BaseCallbackHandler):
         ):
             model_name = self.llm_model.metadata.model_name
             # Need to push the data to via platform service
-            self.stream_log(log=f"Pushing llm usage llm for model {model_name}")
+            self.stream_log(log=f"Pushing llm usage for model {model_name}")
+            llm_token_counter: TokenCounter = TokenCounter.get_llm_token_counts(payload)
             Audit(log_level=self.log_level).push_usage_data(
                 platform_api_key=self.platform_api_key,
-                token_counter=self.token_counter,
+                token_counter=llm_token_counter,
                 event_type=event_type,
                 model_name=self.llm_model.metadata.model_name,
-                **self.kwargs,
+                kwargs=self.kwargs,
             )
 
         elif (
@@ -105,11 +107,12 @@ class UsageHandler(StreamMixin, BaseCallbackHandler):
         ):
             model_name = self.embed_model.model_name
             # Need to push the data to via platform service
-            self.stream_log(log=f"Pushing llm usage llm for model {model_name}")
+            self.stream_log(log=f"Pushing embedding usage for model {model_name}")
             Audit(log_level=self.log_level).push_usage_data(
                 platform_api_key=self.platform_api_key,
                 token_counter=self.token_counter,
                 event_type=event_type,
                 model_name=self.embed_model.model_name,
-                **self.kwargs,
+                kwargs=self.kwargs,
             )
+            self.token_counter.reset_counts()
